# -*- coding: utf-8 -*-
##############################################################################
#
#    OpenERP, Open Source Management Solution
#    Copyright (C) 2012 Akretion
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

from osv import fields, osv
from base_status.base_stage import base_stage
from crm import crm
import time

#differenciates ISSUES and TASKS stages and
#adds features for issue management (like launchpad link…)

_ISSUE_STATE= [('draft', 'New'), ('open', 'In Progress'), ('cancel', 'Cancelled'), ('done', 'Done'), ('pending', 'Pending')]


class project_issue_type(osv.osv):
    _name = 'project.issue.type'
    _description = 'Issue Stage'
    _order = 'sequence'
    _columns = {
        'name': fields.char('Stage Name', required=True),
        'description': fields.text('Description'),
        'sequence': fields.integer('Sequence'),
        'case_default': fields.boolean('Common to All Issues',
                        help="If checked, this stage will not be always visible. It will be hided if there is no issue in this stage"),
        'state': fields.selection(_ISSUE_STATE, 'Related Status', required=True,
                         help="The status of your issue is automatically changed regarding the selected stage. " \
                            "For example, if a stage is related to the status 'Close', when your" \
                            " issue reaches this stage, it is automatically closed.",
                        ),
        'fold': fields.boolean('Default folding',
                        help="If checked, this stage will be folded by default, for example in status bar or kanban view."),
    }
    _defaults = {
        'sequence': 1,
        'state': 'draft',
        'fold': False,
        'case_default': True,
    }

class project_issue(osv.osv):

    _inherit = 'project.issue'


    def write(self, cr, uid, ids, vals, context=None):
        #Update last action date every time the user change the stage, the state or send a new email
        logged_fields = ['stage_id', 'state', 'message_ids']
        if any([field in vals for field in logged_fields]):
            vals['date_action_last'] = time.strftime('%Y-%m-%d %H:%M:%S')
            #self.write_stage_send_note(cr, uid, ids, vals['stage_id'], context=context)
        return super(project_issue, self).write(cr, uid, ids, vals, context)


    _columns = {
        'stage_id': fields.many2one ('project.issue.type', 'Stage',
                        track_visibility='onchange', select=True,
                        domain="[('fold', '=', False)]"),
        'state': fields.related('stage_id', 'state', type="selection", store=True,
                selection=_ISSUE_STATE, string="Status", readonly=True, select=True,
                help='The status is set to \'Draft\', when a case is created.\
                      If the case is in progress the status is set to \'Open\'.\
                      When the case is over, the status is set to \'Done\'.\
                      If the case needs to be reviewed then the status is \
                      set to \'Pending\'.'),
            'support_level' : fields.selection([('normal', 'Normal'), ('urgent', 'Normal'), ('very_urgent', 'Very Urgent')], 'Support Level'),
            'lp_link': fields.char('lp bug report', size=256, help='LaunchPad report link'),
            'user_id': fields.many2one('res.users', 'Assigned to', required=False, select=1, help='Akretion\'s team member assigned to this issue' ),
            'partner_id': fields.many2one('res.partner', 'Contact', select=1, help='Akretion customer\'s team working on or reporting this issue'),
            }

    _defaults = {
            'support_level': 'normal',
            'state': 'draft',
            }



